/**
 * Licensed to Abiquo Holdings S.L. (Abiquo) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package com.abiquo.am.model;

import javax.ws.rs.core.MediaType;
import javax.xml.bind.annotation.XmlRootElement;

import com.abiquo.model.transport.SingleResourceTransportDto;
import com.abiquo.server.core.appslibrary.DatacenterRepositoryDto;

@XmlRootElement(name = "repositoryConfiguration")
public class RepositoryConfigurationDto extends SingleResourceTransportDto
{
    private static final long serialVersionUID = -912929254475352163L;

    /**
     * {@link abiquo.appliancemanager.repositoryLocation} property in the datacenter remote services
     * configuration. Remote repository NFS exported location ('nsf-devel:/opt/vm_repository')
     */
    protected String location;

    /**
     * Capacity of the {@link DatacenterRepositoryDto}, shared by all the EnterpriseRepositories.
     * TODO consider move to {@link RepositoryConfigurationDto}
     */
    private long capacityMb;

    /**
     * Remaining free space in the {@link DatacenterRepositoryDto}, shared by all the
     * EnterpriseRepositories.TODO consider move to {@link RepositoryConfigurationDto}
     */
    private long remainingMb;

    public long getCapacityMb()
    {
        return capacityMb;
    }

    public void setCapacityMb(final long capacityMb)
    {
        this.capacityMb = capacityMb;
    }

    public long getRemainingMb()
    {
        return remainingMb;
    }

    public void setRemainingMb(final long remainingMb)
    {
        this.remainingMb = remainingMb;
    }

    public String getLocation()
    {
        return location;
    }

    public void setLocation(final String location)
    {
        this.location = location;
    }

    @Override
    public String getMediaType()
    {
        return MediaType.APPLICATION_XML;
    }
    
    @Override
    public String getBaseMediaType()
    {
        return MediaType.APPLICATION_XML;
    }
}
