/**
 * Licensed to Abiquo Holdings S.L. (Abiquo) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package com.abiquo.am.model;

import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;

import org.apache.commons.lang.StringUtils;

import com.abiquo.model.enumerator.DiskFormatType;
import com.abiquo.server.core.appslibrary.TemplateDefinitionDto;

/**
 * The materialization of an {@link TemplateDefinition} of a given {@link Datacenter} and
 * Enterprise.
 */
@XmlType
@XmlRootElement(name = "template")
public class TemplateDto extends TemplateDefinitionDto
{
    private static final long serialVersionUID = 6994372893155355385L;

    /** Virtual disk file (.vmdk) path relative to the repository */
    private String diskFilePath;

    /** Optional. Only for vimages instances (bundles) */
    private String masterDiskFilePath;

    /** ######### hardware requirements : TODO move to {@link TemplateDefinitionDto} ######### */

    @Deprecated
    /** Use {@link TemplateDefinitionDto} diskFormatTypeUri: TODO use the DiskFormatEnum in the TemplateDefinitionDto*/
    private DiskFormatType diskFileFormat;

    @Deprecated
    // Use links
    private String iconPath;

    @Deprecated
    // Use links
    private String categoryName;

    private Integer cpu;

    private Long ram;

    private Long hd;

    private MemorySizeUnit ramSizeUnit;

    private MemorySizeUnit hdSizeUnit;

    @Deprecated
    // Use links
    private Integer enterpriseRepositoryId;

    public String getDiskFilePath()
    {
        return diskFilePath;
    }

    public void setDiskFilePath(final String diskFilePath)
    {
        this.diskFilePath = diskFilePath;
    }

    /** Optional. Only for vimages instances (bundles) */
    public String getMasterDiskFilePath()
    {
        return masterDiskFilePath;
    }

    public void setMasterDiskFilePath(final String masterDiskFilePath)
    {
        this.masterDiskFilePath = masterDiskFilePath;
    }

    public DiskFormatType getDiskFileFormat()
    {
        return diskFileFormat;
    }

    public void setDiskFileFormat(final DiskFormatType diskFileFormat)
    {
        this.diskFileFormat = diskFileFormat;
        this.setDiskFormatType(String.valueOf(diskFileFormat.getAlias()));
        // FIXME once TemplateDefinitionDto work with Enum
    }

    public String getIconPath()
    {
        return iconPath;
    }

    public void setIconPath(final String iconPath)
    {
        this.iconPath = iconPath;
    }

    public String getCategoryName()
    {
        return categoryName;
    }

    public void setCategoryName(final String categoryName)
    {
        this.categoryName = StringUtils.strip(categoryName);
    }

    /** TODO get from the EnterpriseRepository link */
    public Integer getEnterpriseRepositoryId()
    {
        return enterpriseRepositoryId;
    }

    /** TODO set to the EnterpriseRepository link */
    public void setEnterpriseRepositoryId(final Integer enterpriseRepositoryId)
    {
        this.enterpriseRepositoryId = enterpriseRepositoryId;
    }

    public Integer getCpu()
    {
        return cpu;
    }

    public void setCpu(final Integer cpu)
    {
        this.cpu = cpu;
    }

    public Long getRam()
    {
        return ram;
    }

    public void setRam(final Long ram)
    {
        this.ram = ram;
    }

    public Long getHd()
    {
        return hd;
    }

    public void setHd(final Long hd)
    {
        this.hd = hd;
    }

    /** default MB */
    public MemorySizeUnit getRamSizeUnit()
    {
        return ramSizeUnit != null ? ramSizeUnit : MemorySizeUnit.MEGABYTE;
    }

    public void setRamSizeUnit(final MemorySizeUnit ramSizeUnit)
    {
        this.ramSizeUnit = ramSizeUnit;
    }

    /** default MB */
    public MemorySizeUnit getHdSizeUnit()
    {
        return hdSizeUnit != null ? hdSizeUnit : MemorySizeUnit.MEGABYTE;
    }

    public void setHdSizeUnit(final MemorySizeUnit hdSizeUnit)
    {
        this.hdSizeUnit = hdSizeUnit;
    }

    @Override
    public String getBaseMediaType()
    {
        return BASE_MEDIA_TYPE;
    }

}
